@@ -7,12 +7,13 @@ import json
 import requests
 import shutil
 import subprocess
+from pathlib import PurePosixPath
 from textwrap import dedent
 from typing import Iterable, List
 from .. import hostenv, config
-from ..types import RunnerTestResults, RunnerTestResultStatus
+from ..types import RunnerSetupStatus, RunnerTestResults, RunnerTestResultStatus, RunnerUpdateStatus
 from ..util import warn, colored, capture_output, exec_or_return, split_image_name
-from ..volume import store_volume
+from ..volume import store_volume, NamedVolume
 from ..__version__ import __version__
 
 
@@ -64,7 +65,10 @@ def run(opts, argv, working_volume = None, extra_env = {}, cpus: int = None, mem
     # doesn't match up well with our use case.  We're aiming to not surprise or
     # confuse the user.
     #
-    missing_volumes = [ vol for vol in opts.volumes if not vol.src.is_dir() ]
+    missing_volumes = [
+        vol for vol in opts.volumes
+             if (vol.dir and not vol.src.is_dir())
+             or not vol.src.exists() ]
 
     if missing_volumes:
         warn("Error: The path(s) given for the following components do not exist")
@@ -117,7 +121,7 @@ def run(opts, argv, working_volume = None, extra_env = {}, cpus: int = None, mem
         *(["--user=%d:%d" % (uid, gid)] if uid and gid else []),
 
         # Map directories to bind mount into the container.
-        *["--volume=%s:/nextstrain/%s" % (v.src.resolve(strict = True), v.name)
+        *["--volume=%s:%s:%s" % (v.src.resolve(strict = True), mount_point(v), "rw" if v.writable else "ro")
             for v in opts.volumes
              if v.src is not None],
 
@@ -143,6 +147,45 @@ def run(opts, argv, working_volume = None, extra_env = {}, cpus: int = None, mem
     ], extra_env)
 
 
+def mount_point(volume: NamedVolume) -> PurePosixPath:
+    """
+    Determine the mount point of *volume* in the container.
+    """
+    if volume.name == "bashrc":
+        return PurePosixPath("/etc/bash.bashrc")
+
+    return PurePosixPath("/nextstrain", volume.name)
+
+
+def setup(dry_run: bool = False, force: bool = False) -> RunnerSetupStatus:
+    if not setup_image(dry_run, force):
+        return False
+
+    return True
+
+
+def setup_image(dry_run: bool = False, force: bool = False) -> bool:
+    """
+    Download the image if it's not already available locally.
+
+    Though not strictly required, by doing this during setup we avoid the
+    initial download on first use instead.
+    """
+    image = DEFAULT_IMAGE
+
+    if not force and image_exists(image):
+        print(f"Using existing local copy of Docker image {image}.")
+        print(f"  Hint: if you want to ignore this existing local copy, re-run `nextstrain setup` with --force.")
+        return True
+
+    update_ok = _update(dry_run)
+
+    if not update_ok:
+        return False
+
+    return True
+
+
 def test_setup() -> RunnerTestResults:
     def test_run():
         try:
@@ -248,10 +291,14 @@ def set_default_config() -> None:
     config.setdefault("docker", "image", latest_build_image(DEFAULT_IMAGE))
 
 
-def update() -> bool:
+def update() -> RunnerUpdateStatus:
     """
     Pull down the latest Docker image build and prune old image versions.
     """
+    return _update()
+
+
+def _update(dry_run: bool = False) -> RunnerUpdateStatus:
     current_image = DEFAULT_IMAGE
     latest_image  = latest_build_image(current_image)
 
@@ -262,16 +309,17 @@ def update() -> bool:
     print()
 
     # Pull the latest image down
-    try:
-        subprocess.run(
-            ["docker", "image", "pull", latest_image],
-            check = True)
-    except (OSError, subprocess.CalledProcessError):
-        return False
+    if not dry_run:
+        try:
+            subprocess.run(
+                ["docker", "image", "pull", latest_image],
+                check = True)
+        except (OSError, subprocess.CalledProcessError):
+            return False
 
-    # Update the config file to point to the new image so we use it by default
-    # going forward.
-    config.set("docker", "image", latest_image)
+        # Update the config file to point to the new image so we use it by default
+        # going forward.
+        config.set("docker", "image", latest_image)
 
     # Prune any old images which are now dangling to avoid leaving lots of
     # hidden disk use around.  We don't use `docker image prune` because we
@@ -281,19 +329,25 @@ def update() -> bool:
     print(colored("bold", "Pruning old images…"))
     print()
 
-    try:
-        images = dangling_images(latest_image) \
-               + old_build_images(latest_image)
+    if not dry_run:
+        try:
+            images = dangling_images(latest_image) \
+                   + old_build_images(latest_image)
 
-        if images:
-            subprocess.run(
-                ["docker", "image", "rm", *images],
-                check = True)
-    except (OSError, subprocess.CalledProcessError) as error:
-        warn()
-        warn("Update succeeded, but an error occurred pruning old image versions:")
-        warn("  ", error)
-        warn()
+            if images:
+                subprocess.run(
+                    ["docker", "image", "rm", *images],
+                    check = True)
+        except (OSError, subprocess.CalledProcessError) as error:
+            warn()
+            warn("Update succeeded, but an error occurred pruning old image versions:")
+            warn("  ", error)
+            warn()
+            warn("This can occur, for example, if you have a `nextstrain build`,")
+            warn("`nextstrain view`, or `nextstrain shell` command still running.")
+            warn()
+            warn("Not to worry, we'll try again the next time you run `nextstrain update`.")
+            warn()
 
     return True
 
